@@ -23,17 +23,9 @@
 #define COMMON_H
 
 #include "myGtk.h"
+#include "config.h"
 
 
-
-#define SCREENW 640   
-#define SCREENH 480  
-
-#define BLOCK_SIZE      25   
-#define BLOCK_OFFSET_X  20   
-#define BLOCK_OFFSET_Y  20   
-#define BLOCK_NUM_X     20   
-#define BLOCK_NUM_Y     15  
 #define BLOCK_NONE       0
 #define BLOCK_STOPPER 0xFF       
 
