@@ -1,13 +1,26 @@
 #!/bin/sh
 
-if [ "$1" = "cross" ]; then
+if [ "$1" = "sl700" ]; then
+    ln -v -f -s config/config-sl700.h config.h
+    ln -v -f -s config/config.mk-sl700 config.mk
+    cp desktop/qmatrix-sl700.desktop desktop/qmatrix.desktop
+elif [ "$1" = "sl300" ]; then
+    ln -v -f -s config/config-sl300.h config.h
+    ln -v -f -s config/config.mk-sl300 config.mk
+    cp desktop/qmatrix-sl300.desktop desktop/qmatrix.desktop
+else
+    echo "usage: $0 sl700 | sl300 cross | native"
+    exit 1
+fi
+
+if [ "$2" = "cross" ]; then
     export CROSSCOMPILE=/opt/Embedix/tools
     export QPEDIR=/opt/Qtopia/sharp
     export QTDIR=/opt/Qtopia/sharp
     export PATH=$QTDIR/bin:$QPEDIR/bin:$CROSSCOMPILE/bin:$PATH
     export TMAKEPATH=/opt/Qtopia/tmake/lib/qws/linux-sharp-g++/
     export LD_LIBRARY_PATH=$QTDIR/lib:$LD_LIBRARY_PATH
-elif [ "$1" = "native" ]; then
+elif [ "$2" = "native" ]; then
     export CROSSCOMPILE=
     export QPEDIR=/opt/Qtopia
     export QTDIR=/opt/Qtopia
@@ -15,13 +28,14 @@ elif [ "$1" = "native" ]; then
     export TMAKEPATH=/opt/Qtopia/tmake/lib/qws/linux-x86-g++/
     export LD_LIBRARY_PATH=$QTDIR/lib:$LD_LIBRARY_PATH
 else
-    echo "usage: $0 cross | native"
+    echo "usage: $0 sl700 | sl300 cross | native"
     exit 1
 fi
 
 TMPDIR=qmatrix_1.0.0
 
 make -C tools
+make -C images clean
 make -C images
 
 tmake -o Makefile qmatrix.pro
